@@ -2,7 +2,7 @@
 #'
 #' Coerces an R object to a [term-vector()].
 #'
-#' `as.term` has been `r lifecycle::badge("soft-deprecated")` for `as_term`.
+#' `as.term` has been `r lifecycle::badge("deprecated")` for `as_term`.
 #'
 #' @inheritParams params
 #'
@@ -18,7 +18,7 @@ as_term <- function(x, ...) UseMethod("as_term")
 #' @export
 as.term <- function(x, ...) {
   out <- UseMethod("as.term")
-  deprecate_soft("0.2.0", "as.term()", "as_term()")
+  deprecate_warn("0.3.7", "as.term()", "as_term()")
   out
 }
 
