@@ -2,7 +2,7 @@
 #'
 #' Gets the name of each parameter for each term.
 #'
-#' The scalar argument is `r lifecycle::badge("defunct")`.
+#' The scalar argument is `r lifecycle::badge("deprecated")`.
 #'
 #' @inheritParams params
 #' @param x A term vector.
@@ -21,7 +21,7 @@ pars_terms <- function(x, scalar = NULL, ...) {
     chkor_vld(vld_s3_class(x, "term"), vld_s3_class(x, "term_rcrd"))
   }
   if (!missing(scalar)) {
-    deprecate_soft("0.2.1", "term::pars_terms(scalar =)")
+    deprecate_warn("0.3.7", "term::pars_terms(scalar =)")
   }
   chk_unused(...)
   x <- as_term_rcrd(x)
