@@ -45,11 +45,12 @@ pars.character <- function(x, scalar = NULL, ...) {
 #' pars(term, scalar = TRUE)
 #' pars(term, scalar = FALSE)
 pars.term <- function(x, scalar = NULL, terms = FALSE, ...) {
-  if(!missing(terms)) {
+  if (!missing(terms)) {
     deprecate_warn("0.2.1", "term::pars(terms =)")
   }
-  if(isTRUE(terms))
+  if (isTRUE(terms)) {
     return(pars_terms(x))
+  }
 
   pars(as_term_rcrd(x), scalar = scalar, ...)
 }
@@ -73,14 +74,13 @@ pars.term <- function(x, scalar = NULL, terms = FALSE, ...) {
 #' pars(term, scalar = FALSE)
 pars.term_rcrd <- function(x, scalar = NULL, ...) {
   # FIXME hack for nlist v0.1.0 and v0.1.1
-  if(identical(scalar, NA)) scalar <- NULL
-  if(!is.null(scalar)) chk_flag(scalar)
+  if (identical(scalar, NA)) scalar <- NULL
+  if (!is.null(scalar)) chk_flag(scalar)
   chk_unused(...)
 
-  if(!is.null(scalar)) {
+  if (!is.null(scalar)) {
     bol <- scalar_term(x)
-    x <- x[is.na(bol) | if(scalar) bol else !bol]
+    x <- x[is.na(bol) | if (scalar) bol else !bol]
   }
   unique(field(x, "par"))
 }
-
