@@ -12,7 +12,7 @@ test_that("npdims.term", {
     c(alpha = 1L, beta = 2L, sigma = 1L)
   )
 
-  lifecycle::expect_defunct(npdims(new_term(c("alpha[1]", "alpha[3]", "beta[1,1]", "beta[2,1]")), terms = TRUE))
+  testthat::expect_error(npdims(new_term(c("alpha[1]", "alpha[3]", "beta[1,1]", "beta[2,1]")), terms = TRUE))
 
   expect_error(npdims(NA_term_), "^`x` must not have any missing values[.]$", class = "chk_error")
 })
